EventIdMap

Struct EventIdMap 

pub struct EventIdMap<E, V>(/* private fields */)
where
    E: Borrow<EventId>;
Available on crate feature state-res only.
A map of event IDs to a type V.

Implementations

Source

impl<E, V> EventIdMap<E, V>
where E: Borrow<EventId>,

pub fn new() -> EventIdMap<E, V>

Create an empty EventIdMap.

pub fn with_capacity(capacity: usize) -> EventIdMap<E, V>

Create an empty EventIdMap with the given capacity.

pub fn clear(&mut self)

Clears the map, removing all key-value pairs.

pub fn len(&self) -> usize

Returns the number of elements in the map.

pub fn is_empty(&self) -> bool

Returns true if the map contains no elements.

pub fn iter(&self) -> EventIdMapIter<'_, E, V>

Gets an iterator over the entries of the map.

pub fn keys(&self) -> EventIdMapKeys<'_, E, V>

Gets an iterator over the keys of the map.

pub fn into_keys(self) -> EventIdMapIntoKeys<E, V>

Gets an iterator over the keys of the map.

pub fn values(&self) -> EventIdMapValues<'_, E, V>

Gets an iterator over the values of the map.

pub fn into_values(self) -> EventIdMapIntoValues<E, V>

Gets an iterator over the values of the map.

Source

impl<E, V> EventIdMap<E, V>
where E: Borrow<EventId> + Eq + Hash,

pub fn contains_event_id(&self, event_id: &EventId) -> bool

Returns true if the map contains a value for the specified event ID.

pub fn get(&self, event_id: &EventId) -> Option<&V>

Returns a reference to the value corresponding to given event ID.

pub fn get_mut(&mut self, event_id: &EventId) -> Option<&mut V>

Returns a mutable reference to the value corresponding to given event ID.

pub fn get_key_value(&self, event_id: &EventId) -> Option<(&E, &V)>

Returns the key-value pair corresponding to the supplied event ID.

pub fn entry(&mut self, event_id: E) -> EventIdMapEntry<'_, E, V>

Gets the given event ID’s corresponding entry in the map for in-place manipulation.

pub fn insert(&mut self, event_id: E, value: V) -> Option<V>

Inserts a key-value pair into the map.

If the map did not have this event ID present, None is returned.

If the map did have this event ID present, the value is updated, and the old value is returned.

pub fn remove(&mut self, event_id: &EventId) -> Option<V>

Removes an event ID from the map, returning the value at the event ID if the event ID was previously in the map.

pub fn remove_entry(&mut self, event_id: &EventId) -> Option<(E, V)>

Removes an event ID from the map, returning the stored event ID and value if the event ID was previously in the map.