pub struct EventIdMap<E, V>(/* private fields */)
where
E: Borrow<EventId>;state-res only.Expand description
A map of event IDs to a type V.
Implementations
Sourceimpl<E, V> EventIdMap<E, V>
impl<E, V> EventIdMap<E, V>
Sourcepub fn new() -> EventIdMap<E, V>
pub fn new() -> EventIdMap<E, V>
Create an empty EventIdMap.
Sourcepub fn with_capacity(capacity: usize) -> EventIdMap<E, V>
pub fn with_capacity(capacity: usize) -> EventIdMap<E, V>
Create an empty EventIdMap with the given capacity.
Sourcepub fn iter(&self) -> EventIdMapIter<'_, E, V> ⓘ
pub fn iter(&self) -> EventIdMapIter<'_, E, V> ⓘ
Gets an iterator over the entries of the map.
Sourcepub fn keys(&self) -> EventIdMapKeys<'_, E, V> ⓘ
pub fn keys(&self) -> EventIdMapKeys<'_, E, V> ⓘ
Gets an iterator over the keys of the map.
Sourcepub fn into_keys(self) -> EventIdMapIntoKeys<E, V> ⓘ
pub fn into_keys(self) -> EventIdMapIntoKeys<E, V> ⓘ
Gets an iterator over the keys of the map.
Sourcepub fn values(&self) -> EventIdMapValues<'_, E, V> ⓘ
pub fn values(&self) -> EventIdMapValues<'_, E, V> ⓘ
Gets an iterator over the values of the map.
Sourcepub fn into_values(self) -> EventIdMapIntoValues<E, V> ⓘ
pub fn into_values(self) -> EventIdMapIntoValues<E, V> ⓘ
Gets an iterator over the values of the map.
Sourceimpl<E, V> EventIdMap<E, V>
impl<E, V> EventIdMap<E, V>
Sourcepub fn contains_event_id(&self, event_id: &EventId) -> bool
pub fn contains_event_id(&self, event_id: &EventId) -> bool
Returns true if the map contains a value for the specified event ID.
Sourcepub fn get(&self, event_id: &EventId) -> Option<&V>
pub fn get(&self, event_id: &EventId) -> Option<&V>
Returns a reference to the value corresponding to given event ID.
Sourcepub fn get_mut(&mut self, event_id: &EventId) -> Option<&mut V>
pub fn get_mut(&mut self, event_id: &EventId) -> Option<&mut V>
Returns a mutable reference to the value corresponding to given event ID.
Sourcepub fn get_key_value(&self, event_id: &EventId) -> Option<(&E, &V)>
pub fn get_key_value(&self, event_id: &EventId) -> Option<(&E, &V)>
Returns the key-value pair corresponding to the supplied event ID.
Sourcepub fn entry(&mut self, event_id: E) -> EventIdMapEntry<'_, E, V>
pub fn entry(&mut self, event_id: E) -> EventIdMapEntry<'_, E, V>
Gets the given event ID’s corresponding entry in the map for in-place manipulation.
Sourcepub fn insert(&mut self, event_id: E, value: V) -> Option<V>
pub fn insert(&mut self, event_id: E, value: V) -> Option<V>
Inserts a key-value pair into the map.
If the map did not have this event ID present, None is returned.
If the map did have this event ID present, the value is updated, and the old value is returned.
Sourcepub fn remove(&mut self, event_id: &EventId) -> Option<V>
pub fn remove(&mut self, event_id: &EventId) -> Option<V>
Removes an event ID from the map, returning the value at the event ID if the event ID was previously in the map.
Sourcepub fn remove_entry(&mut self, event_id: &EventId) -> Option<(E, V)>
pub fn remove_entry(&mut self, event_id: &EventId) -> Option<(E, V)>
Removes an event ID from the map, returning the stored event ID and value if the event ID was previously in the map.